@@ -1,7 +1,7 @@
 package App::depak;
 
 our $DATE = '2015-07-27'; # DATE
-our $VERSION = '0.44'; # VERSION
+our $VERSION = '0.45'; # VERSION
 
 use 5.010001;
 use strict;
@@ -90,7 +90,7 @@ sub _build_lib {
         }
     }
 
-    for (@{ $self->{include} // [] }) {
+    for (@{ $self->{include_module} // [] }) {
         $log->debugf("  Adding module: %s (included)", $_);
         $mod_paths{$_} = undef;
     }
@@ -178,7 +178,7 @@ sub _build_lib {
             }
         }
 
-        if ($self->{exclude} && $mod ~~ @{ $self->{exclude} }) {
+        if ($self->{exclude_module} && $mod ~~ @{ $self->{exclude_module} }) {
             $log->infof("Excluding %s: skipped", $mod);
             next MOD_TO_FILTER;
         }
@@ -447,7 +447,7 @@ _
             tags => ['category:output'],
             'x.schema.entity' => 'filename',
         },
-        include => {
+        include_module => {
             summary => 'Include extra modules',
             'summary.alt.plurality.singular' => 'Include an extra module',
             description => <<'_',
@@ -457,7 +457,7 @@ here.
 
 _
             schema => ['array*' => of => 'str*'],
-            cmdline_aliases => { I=>{} },
+            cmdline_aliases => { I=>{}, include=>{} },
             tags => ['category:module-selection'],
             'x.schema.element_entity' => 'modulename',
         },
@@ -488,7 +488,7 @@ _
             tags => ['category:module-selection'],
             'x.schema.element_entity' => 'distname',
         },
-        exclude => {
+        exclude_module => {
             summary => 'Modules to exclude',
             'summary.alt.plurality.singular' => 'Exclude a module',
             description => <<'_',
@@ -497,7 +497,7 @@ When you don't want to include a module, specify it here.
 
 _
             schema => ['array*' => of => 'str*'],
-            cmdline_aliases => { E => {} },
+            cmdline_aliases => { E => {}, exclude => {} },
             tags => ['category:module-selection'],
             'x.schema.element_entity' => 'modulename',
         },
@@ -773,9 +773,9 @@ sub depak {
 
     # for convenience of completion in bash, we allow / to separate namespace.
     # we convert it back to :: here.
-    for (@{ $self->{exclude} // [] },
+    for (@{ $self->{exclude_module} // [] },
          @{ $self->{exclude_dist} // [] },
-         @{ $self->{include} // [] },
+         @{ $self->{include_module} // [] },
          @{ $self->{include_dist} // [] },
          @{ $self->{use} // [] },
      ) {
@@ -953,7 +953,7 @@ App::depak - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.44 of App::depak (from Perl distribution App-depak), released on 2015-07-27.
+This document describes version 0.45 of App::depak (from Perl distribution App-depak), released on 2015-07-27.
 
 =head1 SYNOPSIS
 
@@ -995,14 +995,6 @@ or:
 
 {en_US Keep temporary directory for debugging}.
 
-=item * B<exclude> => I<array[str]>
-
-{en_US Modules to exclude}.
-
-{en_US 
-When you don't want to include a module, specify it here.
-}
-
 =item * B<exclude_core> => I<bool> (default: 1)
 
 {en_US Whether to exclude core modules}.
@@ -1021,6 +1013,14 @@ distribution. Will determine other modules from the C<.packlist> file.
 
 {en_US Exclude modules from a list in a file}.
 
+=item * B<exclude_module> => I<array[str]>
+
+{en_US Modules to exclude}.
+
+{en_US 
+When you don't want to include a module, specify it here.
+}
+
 =item * B<exclude_pattern> => I<array[str]>
 
 {en_US Regex patterns of modules to exclude}.
@@ -1045,15 +1045,6 @@ option requires that C<lcpan> is installed and a fairly recent lcpan index is
 available.
 }
 
-=item * B<include> => I<array[str]>
-
-{en_US Include extra modules}.
-
-{en_US 
-When the tracing process fails to include a required module, you can add it
-here.
-}
-
 =item * B<include_dir> => I<array[str]>
 
 {en_US Include extra modules under directories}.
@@ -1072,6 +1063,15 @@ distribution. Will determine other modules from the C<.packlist> file.
 
 {en_US Include extra modules from a list in a file}.
 
+=item * B<include_module> => I<array[str]>
+
+{en_US Include extra modules}.
+
+{en_US 
+When the tracing process fails to include a required module, you can add it
+here.
+}
+
 =item * B<include_prereq> => I<array[str]>
 
 {en_US 
